import java.util.List;
import java.util.ArrayList;

public class Hanoi
{
	 protected List<Peg> pegs;
	 protected final int N;
	 protected final int nPegs = 3;

	 private Peg left() {
		  return peg(PegPosition.LEFT);
	 }

	 private Peg middle() {
		  return peg(PegPosition.MIDDLE);
	 }

	 private Peg right() {
		  return peg(PegPosition.RIGHT);
	 }

	 private Peg peg(PegPosition position) {
		  return pegs.get(position.toInt());
	 }

	 @Override
	 public String toString() {
		  List<List<String>> pegS = new ArrayList<List<String>>(nPegs);
		  for (PegPosition p : PegPosition.values())
				pegS.add(p.toInt(), peg(p).toStringList());
		  String[] str = new String[pegS.get(0).size()];
		  for (int row = 0; row < str.length; row++)
				str[row] = pegS.get(0).get(row)
					 + " " + pegS.get(1).get(row)
					 + " " + pegS.get(2).get(row);
		  return String.join("\n", str);
	 }

	 // move top disk from `source' to `destination'
	 public void move(PegPosition source, PegPosition destination) {
		  int disk = peg(source).remove();
		  peg(destination).add(disk);
	 }

	 // move top disk from `source' to `destination'
	 // return description of move and board before the move if `showBoard'
	 public String move(PegPosition source, PegPosition destination, boolean showBoard) {
		  String move = "";
		  if (showBoard)
				move = this + "\n";
		  move = move + "Move top disk from " + source + " peg to " + destination + " peg.";
		  move(source, destination);
		  return move;
	 }

	 // initialize board with `N' sorted disks on left peg
	 Hanoi(int N) {
	 	  if (N < 1)
	 			throw new IllegalArgumentException("Number of disks must be positive: " + N);
	 	  this.N = N;
	 	  pegs = new ArrayList<Peg>();
	 	  pegs.add(PegPosition.LEFT.toInt(), new Peg(N, N));    // left peg: N pegs
	 	  pegs.add(PegPosition.MIDDLE.toInt(), new Peg(0, N));  // middle peg: 0 pegs
	 	  pegs.add(PegPosition.RIGHT.toInt(), new Peg(0, N));   // right peg: 0 pegs
	 }
}
