import java.util.List;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;


enum PegPosition
{
	 LEFT(0), MIDDLE(1), RIGHT(2);

	 private int val;

	 PegPosition(int val) {
		  this.val = val;
	 }

	 public int toInt() {
		  return val;
	 }
}


public class Peg
{
	 // list of disks on peg, from bottom to top
	 private List<Integer> disks;

	 private final int N;

	 // initialize peg with `n' sorted disks
	 // and make room for a total of `N' disks
	 Peg(int n, int N) {
		  this.N = N;
		  disks = new ArrayList<Integer>();
		  for (int disk = n; disk >= 1; disk--)
				disks.add(disk);
		  checkInv();
	 }

	 // number of disks on peg
	 public int count() {
		  return disks.size();
	 }

	 // add `disk' to top of peg
	 public void add(int disk) {
		  disks.add(disk);
		  checkInv();
	 }

	 // remove and return disk at top of peg
	 public int remove() {
		  int disk = disks.remove(count() - 1);
		  checkInv();
		  return disk;
	 }

	 // check that disks are sorted
	 // throw exception is they are not
	 public void checkInv() {
		  for (int k = 0; k < count() - 1; k++)
				if (disks.get(k) <= disks.get(k + 1))
					 throw new IllegalStateException("Unsorted disks on peg: " + toString());
	 }

	 // list of strings representing the peg content
	 // from top to bottom
	 public List<String> toStringList() {
		  final int nRows = N + 2;
		  final int nCols = N + 2;
		  List<String> pegS = new ArrayList<>(nRows);
		  pegS.add(0, repeat('-', nCols));
		  for (int j = 1; j < nRows; j++) {
				if (j <= count())
					 pegS.add(j, diskElement(disks.get(j - 1)));
				else
					 pegS.add(j, repeat(' ', nCols));
		  }
		  Collections.reverse(pegS);
		  return pegS;
	 }

	 @Override
	 public String toString() {
		  return String.join("\n", toStringList());
	 }

	 private static String repeat(char ch, int x) {
		  char[] chars = new char[x];
		  java.util.Arrays.fill(chars, ch);
		  return new String(chars);
	 }

	 private String diskElement(int disk) {
		  String s = repeat('*', disk);
		  return " " + String.format("%1$-" + N + "s", s) + " ";
	 }
}
